---
title: Configuration
---

### Configuration

Below is a list of available configuration with default values:

    "example" => [
        "type"   => "anomaly.field_type.relationship",
        "config" => [
            "related"        => null,
            "mode"           => "lookup",
            "key_name"       => null,
            "title_name"     => null,
            "value_table"    => null,
            "selected_table" => null,
            "lookup_table"   => null,
            "default_value"  => null,
            "handler"        => "\Anomaly\RelationshipFieldType\Handler\Related@handle",
        ]
    ]

###### Configuration

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Example</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

related

</td>

<td>

`\Anomaly\UsersModule\User\UserModel`

</td>

<td>

The related model or stream dot notation (`namespace.stream`).

</td>

</tr>

<tr>

<td>

mode

</td>

<td>

dropdown

</td>

<td>

The input mode. Valid options are `lookup`, `search`, and `dropdown`.

</td>

</tr>

<tr>

<td>

key_name

</td>

<td>

slug

</td>

<td>

The name of the key field. Default is `id`. Only applies to `dropdown` mode.

</td>

</tr>

<tr>

<td>

title_name

</td>

<td>

name

</td>

<td>

The name of the title field. Default is the `title_column`. Only applies to `dropdown` mode.

</td>

</tr>

<tr>

<td>

value_table

</td>

<td>

`\App\Example\MyValueTable`

</td>

<td>

The builder for the value table.

</td>

</tr>

<tr>

<td>

selected_table

</td>

<td>

`\App\Example\MySelectedTable`

</td>

<td>

The builder for the selections table.

</td>

</tr>

<tr>

<td>

lookup_table

</td>

<td>

`\App\Example\MyLookupTable`

</td>

<td>

The builder for the lookup table.

</td>

</tr>

<tr>

<td>

handler

</td>

<td>

`\App\Example\MyOptions@handle`

</td>

<td>

The option handler.

</td>

</tr>

</tbody>

</table>


#### Option Handlers

Option handlers are responsible for setting the available options on the field type. You can define your own option handler to add your own logic to available options.

You can define custom handlers as a callable string where `@handle` will be assumed if no method is provided:

    "handler" => \App\Example\MyOptions::class // Assumes @handle

Option handlers can also a handler with a closure:

    "example" => [
        "config" => [
            "handler" => function (RelationshipFieldType $fieldType, ExampleRepositoryInterface $entries) {
                $fieldType->setOptions($entries->getCustomEntries()->pluck('title', 'id')->all());
            }
        ]
    ]

> Closures can not be stored in the database so your closure type handlers must be set / overridden from the form builder.{.note}


##### Writing Option Handlers

Writing custom option handlers is easy. To begin create a class with the method you defined in the config option.

    "handler" => "App/Example/MyOptions@handle"

The handler string is called via Laravel's service container. The `RelationshipFieldType $fieldType` is passed as an argument.

> Handlers are called through Laravel's service container so method and class injection is supported.{.tip}

    <?php namespace App/Example;

    class MyOptions
    {
        public function handle(RelationshipFieldType $fieldType, ExampleRepositoryInterface $entries) {
            $fieldType->setOptions(
                $entries->getCustomEntries()->pluck('title', 'id')->all()
            );
        }
    }

